@@ -20,6 +20,8 @@ my $fh = IO::File->new( $dist_ini, 'r' );
 my $ua = Mojo::UserAgent->new;
 
 my $prereqs = 0;
+my @items;
+
 while ( my $line = $fh->getline ) {
     next if !$line;
     
@@ -38,5 +40,27 @@ while ( my $line = $fh->getline ) {
     
     next if !$release;
     
-    print sprintf "=item * %s\n\n%s\n\n", $module, $release->{abstract};
-}
\ No newline at end of file
+    push @items, sprintf "=item * %s\n\n%s\n\n", $module, $release->{abstract};
+}
+
+my $pm_file = File::Spec->catfile(
+    dirname( __FILE__ ),
+    qw/.. lib Task LiveDVD/,
+    'FrankfurtPM.pm',
+);
+my $content = do{ local (@ARGV, $/) = $pm_file; <> };
+
+my $podheader = qq{
+=head1 MODULES REQUIRED
+
+=over 4
+
+};
+my $pod = join '', @items;
+my $podend = "=back";
+$content =~ s/__END__.*/__END__\n$podheader$pod$podend/s;
+
+my $pm_fh = IO::File->new( $pm_file, 'w' );
+$pm_fh->binmode( 'utf-8' );
+$pm_fh->print( $content );
+$pm_fh->close;
